import { MaskOptions } from '@highlight-ui/input';
import flatpickr from 'flatpickr';
/**
 * Validates a string that represents a date written in a specific format
 * against the list of disabled dates.
 * An incomplete string is considered valid.
 * It is highly specific for the `imask` date validation use-case.
 * @param inputValue string that represents a date
 * @param dateFormat string that describes the date format for the `inputValue`
 * @param dateAsStringRegExp used to test the string for completeness
 * @param disabledDates a list of `Date` objects, representing the disabled dates
 */
export declare const isIMaskValueValidDate: (inputValue: string, dateFormat: string, dateAsStringRegExp: RegExp, disabledDates?: Date[] | undefined) => boolean;
declare enum AvailableLocalesEnum {
    'en-GB' = "en-GB",
    'de-DE' = "de-DE",
    'es-ES' = "es-ES",
    'fr-FR' = "fr-FR",
    'nl-NL' = "nl-NL",
    'it-IT' = "it-IT"
}
export declare type AvailableLocales = keyof typeof AvailableLocalesEnum;
export declare const hourMask: (value: string) => boolean;
declare type TimeConfig = {
    /**
     * A name of the icon for the input
     */
    iconName: string;
    /**
     * A format for `date-fns` to understand
     * https://date-fns.org/v2.16.1/docs/parse
     */
    parseFormat: string;
    /**
     * `react-imask` props
     * https://github.com/uNmAnNeR/imaskjs/blob/master/packages/react-imask/src/mixin.js#L6
     */
    maskOptions: MaskOptions;
    /**
     * A placeholder for the input
     */
    placeholder: string;
};
declare type TimeConfigFactory = () => TimeConfig;
/**
 * `DateConfig` shares a lot with the `TimeConfig`, therefore it extends it.
 */
declare type DateConfig = TimeConfig & {
    /**
     * Format options for `flatpickr`
     * https://flatpickr.js.org/formatting/
     */
    flatPickrFormat: string;
    /**
     * A locale for the `flatpickr`
     * https://flatpickr.js.org/localization/
     */
    flatPickrLocale: flatpickr.CustomLocale;
};
declare type DateConfigFactoryOptions = {
    minDate?: Date;
    maxDate?: Date;
    disabledDates?: Date[];
};
declare type DateConfigFactory = (options?: DateConfigFactoryOptions) => DateConfig;
export declare const getTimeConfigByLocale: (locale: AvailableLocales) => TimeConfigFactory;
export declare const getDateConfigByLocale: (locale: AvailableLocales) => DateConfigFactory;
export {};
